# ifndef yyMakeRemapping
# define yyMakeRemapping

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* MakeRemapping_Exit) ARGS ((void));

extern void MakeRemapping ARGS ((tTree t));

extern void BeginMakeRemapping ARGS ((void));
extern void CloseMakeRemapping ARGS ((void));

# endif
